MethodChannelZoAppBlocker class

Inheritance

Constructors

MethodChannelZoAppBlocker()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

blockAll() → Future<void>
override
blockApps(List<String> identifiers) → Future<void>
override
checkNotificationPermission() → Future<String>
override
checkOverlayPermission() → Future<String>
override
checkUsageStatsPermission() → Future<String>
override
clearBlockActivityLog() → Future<void>
override
getAppIcon(String packageName) → Future<List<int>?>
override
getApps() → Future<List<Map<String, dynamic>>>
override
getAppTimeLimits() → Future<List<Map<String, dynamic>>>
override
getBlockActivityLog() → Future<List<Map<String, dynamic>>>
override
getBlockedApps() → Future<List<Map<String, dynamic>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAppTimeLimit(String packageName) → Future<void>
override
requestNotificationPermission() → Future<void>
override
requestOverlayPermission() → Future<void>
override
requestUsageStatsPermission() → Future<void>
override
resetAppUsage(String packageName) → Future<void>
override
saveBlockScreenCallbackHandle(int rawHandle) → Future<void>
Saves the callback handle for the block screen Dart entrypoint.
override
setAppTimeLimit({required String packageName, required int dailyLimitMinutes}) → Future<void>
override
setNotificationConfig(Map<String, String> config) → Future<void>
override
toString() → String
A string representation of this object.
inherited
unblockAll() → Future<void>
override
unblockApps(List<String> identifiers) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited