ZoAppBlockerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ZoAppBlockerPlatform
Implementers

Constructors

ZoAppBlockerPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

blockAll() → Future<void>
blockApps(List<String> identifiers) → Future<void>
checkNotificationPermission() → Future<String>
checkOverlayPermission() → Future<String>
checkUsageStatsPermission() → Future<String>
clearBlockActivityLog() → Future<void>
getAppIcon(String packageName) → Future<List<int>?>
getApps() → Future<List<Map<String, dynamic>>>
getAppTimeLimits() → Future<List<Map<String, dynamic>>>
getBlockActivityLog() → Future<List<Map<String, dynamic>>>
getBlockedApps() → Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAppTimeLimit(String packageName) → Future<void>
requestNotificationPermission() → Future<void>
requestOverlayPermission() → Future<void>
requestUsageStatsPermission() → Future<void>
resetAppUsage(String packageName) → Future<void>
saveBlockScreenCallbackHandle(int rawHandle) → Future<void>
Saves the callback handle for the block screen Dart entrypoint.
setAppTimeLimit({required String packageName, required int dailyLimitMinutes}) → Future<void>
setNotificationConfig(Map<String, String> config) → Future<void>
toString() → String
A string representation of this object.
inherited
unblockAll() → Future<void>
unblockApps(List<String> identifiers) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ZoAppBlockerPlatform
getter/setter pair