AppInfo class
A model representing an application installed on the device or a category of applications.
Constructors
Properties
- appName → String
-
The human-readable name of the application (e.g., 'Facebook').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Uint8List?
-
An optional byte array containing the application's icon.
final
- packageName → String
-
The unique identifier of the application.
On Android, this is the package name (e.g., 'com.facebook.katana').
On iOS, this might be a unique opaque token.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited