MethodChannelZoAppBlocker class

Inheritance

Constructors

MethodChannelZoAppBlocker()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blockAll() Future<void>
override
blockApps(List<String> identifiers) Future<void>
override
checkAccessibilityPermission() Future<String>
override
checkNotificationPermission() Future<String>
override
getAppIcon(String packageName) Future<List<int>?>
override
getApps() Future<List<Map<String, dynamic>>>
override
getBlockedApps() Future<List<Map<String, dynamic>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestAccessibilityPermission() Future<void>
override
requestNotificationPermission() Future<void>
override
setBlockScreenConfig(Map<String, String> config) Future<void>
override
toString() String
A string representation of this object.
inherited
unblockAll() Future<void>
override
unblockApps(List<String> identifiers) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited