ZoAppBlockerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- ZoAppBlockerPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
blockAll(
) → Future< void> -
blockApps(
List< String> identifiers) → Future<void> -
checkAccessibilityPermission(
) → Future< String> -
checkNotificationPermission(
) → Future< String> -
getAppIcon(
String packageName) → Future< List< int> ?> -
getApps(
) → Future< List< Map< >String, dynamic> > -
getBlockedApps(
) → Future< List< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestAccessibilityPermission(
) → Future< void> -
requestNotificationPermission(
) → Future< void> -
setBlockScreenConfig(
Map< String, String> config) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
-
unblockAll(
) → Future< void> -
unblockApps(
List< String> identifiers) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ZoAppBlockerPlatform
-
getter/setter pair